@@ -1,7 +1,7 @@
 """Unofficial API wrapper for Metabase
 """
 
-__version__ = "0.6.0"
+__version__ = "0.7.0"
 
 from metabase_tools.exceptions import (
     AuthenticationFailure,
@@ -15,10 +15,10 @@ from metabase_tools.exceptions import (
     RequestFailure,
 )
 from metabase_tools.metabase import MetabaseApi
-from metabase_tools.models.card import Card
-from metabase_tools.models.collection import Collection
-from metabase_tools.models.database import Database
-from metabase_tools.models.user import User
+from metabase_tools.models.card_model import CardItem, CardQueryResult
+from metabase_tools.models.collection_model import CollectionItem
+from metabase_tools.models.database_model import DatabaseItem
+from metabase_tools.models.user_model import UserItem
 from metabase_tools.tools import MetabaseTools
 
 __all__ = (
@@ -32,9 +32,10 @@ __all__ = (
     "NoUpdateProvided",
     "RequestFailure",
     "MetabaseApi",
-    "Card",
-    "Collection",
-    "Database",
-    "User",
+    "CardItem",
+    "CardQueryResult",
+    "CollectionItem",
+    "DatabaseItem",
+    "UserItem",
     "MetabaseTools",
 )
